@@ -36,6 +36,8 @@ class DataStock1(DataStock0):
     # Fixed (class-wise) dictionary of default properties
     _ddef = {
         'params': {
+            'dref': {
+            },
             'ddata': {
                 'units':  (str, 'a.u.'),
                 'dim':    (str, 'unknown'),
@@ -43,6 +45,8 @@ class DataStock1(DataStock0):
                 'name':   (str, 'unknown'),
                 'source': (str, 'unknown'),
             },
+            'dobj': {
+            },
          },
     }
 
@@ -137,8 +141,8 @@ class DataStock1(DataStock0):
             dobj0=self._dobj,
             propagate=propagate,
             reserved_keys=self._reserved_keys,
-            ddefparams_data=self._ddef['params']['ddata'],
-            ddefparams_obj=self._ddef['params']['dobj'],
+            ddefparams_data=self._ddef['params'].get('ddata'),
+            ddefparams_obj=self._ddef['params'].get('dobj'),
             data_none=self._data_none,
             max_ndim=self._max_ndim,
         )
@@ -153,8 +157,8 @@ class DataStock1(DataStock0):
             dobj0=self._dobj,
             propagate=propagate,
             reserved_keys=self._reserved_keys,
-            ddefparams_data=self._ddef['params']['ddata'],
-            ddefparams_obj=self._ddef['params']['dobj'],
+            ddefparams_data=self._ddef['params'].get('ddata'),
+            ddefparams_obj=self._ddef['params'].get('dobj'),
             data_none=self._data_none,
             max_ndim=self._max_ndim,
         )
@@ -170,8 +174,8 @@ class DataStock1(DataStock0):
             ddata0=self._ddata,
             dref0=self._dref,
             reserved_keys=self._reserved_keys,
-            ddefparams_data=self._ddef['params']['ddata'],
-            ddefparams_obj=self._ddef['params']['dobj'],
+            ddefparams_data=self._ddef['params'].get('ddata'),
+            ddefparams_obj=self._ddef['params'].get('dobj'),
             data_none=self._data_none,
             max_ndim=self._max_ndim,
         )
@@ -255,12 +259,16 @@ class DataStock1(DataStock0):
 
         """
         which, dd = self.__check_which(which, return_dict=True)
-        _class1_check._set_param(
+        param = _class1_check._set_param(
             dd=dd, dd_name=which,
             param=param, value=value, ind=ind, key=key,
             distribute=distribute,
         )
 
+        # if param refers to an object => update
+        if param in self._dobj.keys():
+            self.update()
+
     def add_param(
         self,
         param,
@@ -269,13 +277,17 @@ class DataStock1(DataStock0):
     ):
         """ Add a parameter, optionnally also set its value """
         which, dd = self.__check_which(which, return_dict=True)
-        _class1_check._add_param(
+        param = _class1_check._add_param(
             dd=dd,
             dd_name=which,
             param=param,
             value=value,
         )
 
+        # if param refers to an object => update
+        if param in self._dobj.keys():
+            self.update()
+
     def remove_param(
         self,
         param=None,
